<?php
if ( !defined( 'IN_CMS' ) ) {
    exit();
}

use \IoC;
use \Flash;
use \Configuration;
use models\Template;
use models\Role;
use models\Permission;
use models\RolePermission;

if ( !class_exists( 'plugins\\antispam\\library\\InvisibleCaptcha' ) ) {
    $flash = new Flash();
    $i18n = IoC::resolve( 'i18n' );
    $flash->error( $i18n->__( 'required_plugin_missing', 'antispam' ) );
    return false;
}
$schema = IoC::resolve( 'sqlschema' );

$schema->dropTableIfexists( 'blog_post' );
$schema->dropTableIfexists( 'blog_comment' );

$schema->createTable( 'blog_post', [
    'post_id' => ['integer', ['not_null' => true, 'primary_key' => true, 'identity' => true]],
    'title' => ['varchar', ['length' => 100, 'not_null' => true]],
    'description' => ['varchar', ['length' => 255, 'default'=> 'NULL']],
    'language' => ['varchar', ['length' => 2, 'default'=> 'NULL']],
    'slug' => ['varchar', ['length' => 100, 'default'=> 'NULL']],
    'summary' => ['text', ['default'=> 'NULL']],
    'body' => ['clob', ['default'=> 'NULL']],
    'css' => ['text', ['default'=> 'NULL']],
    'js' => ['text', ['default'=> 'NULL']],
    'status' => ['smallint', ['not_null' => true]],
    'user_id' => ['integer', ['default' => 'NULL']],
    'allow_comments' => ['boolean'],
    'publication_date' => ['date', ['not_null' => true]],
    'publication_time' => ['time', ['not_null' => true]],
    'created_at' => ['datetime', ['not_null' => true]],
    'updated_at' => ['datetime', ['default' => 'NULL']]
] );
$schema->addIndex( 'UX_blog_post', 'blog_post', 'slug', true );

$schema->addForeignKey( 'FK_blog_post', 'blog_post', 'user_id', 'user', 'user_id', 'SET NULL', 'CASCADE' );

$schema->createTable( 'blog_comment', [
    'comment_id' => ['integer', ['not_null' => true, 'primary_key' => true, 'identity' => true]],
    'name' => ['varchar', ['length' => 100, 'default'=> 'NULL']],
    'email' => ['varchar', ['length' => 255, 'default'=> 'NULL']],
    'post_id' => ['integer', ['default' => 'NULL']],
    'body' => ['clob', ['default'=> 'NULL']],
    'status' => ['smallint', ['not_null' => true]],
    'created_at' => ['datetime', ['not_null' => true]],
    'updated_at' => ['datetime', ['default' => 'NULL']]
]);

$schema->addForeignKey( 'FK_blog_comment', 'blog_comment', 'post_id', 'blog_post', 'post_id', 'CASCADE', 'CASCADE' );

$configurationHandler = IoC::resolve( 'databaseConfigurationHandler' );
$settings = new Configuration( $configurationHandler );

// if ( \Template::exists( ['name' => 'Blog index'] ) ) {
//     return false;
// }
$template = new Template();
$template->name = 'Blog index';
$template->content_type = 'text/html';
$template->content = file_get_contents ( dirname( __FILE__ ) . DS . TEMPLATES_DIR . 'post' . DS . 'index.html' );
$template->save();

$settings['blog.index_template'] = $template->template_id;

// if ( \Template::exists( ['name' => 'Blog post'] ) ) {
//     return false;
// }
$template = new Template();
$template->name = 'Blog post';
$template->content_type = 'text/html';
$template->content = file_get_contents ( dirname( __FILE__ ) . DS . TEMPLATES_DIR . 'post' . DS . 'show.html' );
$template->save();

$settings['blog.post_template'] = $template->template_id;

// if ( \Template::exists( ['name' => 'Blog sidebar'] ) ) {
//     return false;
// }
$template = new Template();
$template->name = 'Blog sidebar';
$template->content_type = 'text/html';
$template->content = file_get_contents ( dirname( __FILE__ ) . DS . TEMPLATES_DIR . '_sidebar.html' );
$template->save();

$settings['blog.sidebar'] = $template->template_id;

$settings['blog.posts_per_page'] = 10;
$settings['blog.moderate_comments'] = 1;
$settings['blog.spam_keywords'] = null;

$configurationHandler->save();

$permissions = [
    'blog.view_blog_posts',
    'blog.create_blog_post',
    'blog.update_blog_post',
    'blog.delete_blog_post',
    'blog.moderate_comments'
    
];
foreach ( $permissions as $name ) {
    $permission = new Permission( ['name' => $name] );
    $permission->save();
            
    $role = Role::findOne( ['name' => 'administrator'] );
    $rolePermission = new RolePermission( ['role_id' => $role->role_id, 'permission_id' => $permission->permission_id] );
    $rolePermission->save();

    $role = Role::findOne( ['name' => 'developer'] );
    $rolePermission = new RolePermission( ['role_id' => $role->role_id, 'permission_id' => $permission->permission_id] );
    $rolePermission->save();

    $role = Role::findOne( ['name' => 'editor'] );
    $rolePermission = new RolePermission( ['role_id' => $role->role_id, 'permission_id' => $permission->permission_id] );
    $rolePermission->save();
}

$logger = IoC::resolve( 'logger' );
$logger->write( sprintf( '[%s] [%s] [%s] Plugin blog successfully installed.', date( 'Y-m-d H:i:s' ), __FILE__, 'info' ) );

return true;
