<?php
namespace plugins\blog\models;

/**
 * Comment model class
 * @author Jérôme Brilland
 * @version 2.0
 * @copyright (c) 2021, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class Comment extends \ActiveRecord {

    const PENDING = 0;
    const APPROVED = 1;
    const SPAM = 2;

    protected static $tableName = 'blog_comment';

    protected static $primaryKey = 'comment_id';

    protected function validate() {
        $i18n = \IoC::resolve( 'i18n' );
        $this->validateMaxLength( 'name', 100, $i18n->__( 'too_long_name', 100 ) );
        $this->validateNotEmpty( 'name', $i18n->__( 'blog.name_cannot_be_empty' ) );
        $this->validateMaxLength( 'email', 320, $i18n->__( 'blog.too_long_email', 320 ) );
        $this->validateNotEmpty( 'email', $i18n->__( 'blog.email_cannot_be_empty' ) );
        $this->validateEmail( 'email', $i18n->__( 'blog.invalid_email' ) );
        $this->validateNotEmpty( 'body', $i18n->__( 'blog.body_cannot_be_empty' ) );
    }

    protected function beforeInsert() {
        $settings = \IoC::resolve( 'settings' );
        if ( $this->isSpam() ) {
            $this->status = Comment::SPAM;
        } else if ( $settings['blog.moderate_comments'] ) {
            $this->status = Comment::PENDING;
        } else {
            $this->status = Comment::APPROVED;
        }
        $this->name = trim( $this->name );
    }

    protected function isSpam() {
        $settings = \IoC::resolve( 'settings' );

        //duplicate spam
        if ( self::exists( ['email' => $this->email, 'status' => Comment::SPAM] ) ) {
            return true;
        }

        //check keywords
        $badWords = $settings['blog.spam_keywords'];
        if ( !empty( $badWords ) ) {
            $words = explode( ',', $badWords );

            foreach( $words as $word ) {
                if ( strpos( $this->body, $word ) ) {
                    return true;
                }
            }
        }

        return false;
    }
}
